@@ -1,9 +1,9 @@
 package Net::DNS::SEC::EdDSA;
 
-#
-# $Id: EdDSA.pm 1701 2018-07-28 07:36:34Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1701 $)[1];
+use strict;
+use warnings;
+
+our $VERSION = (qw$Id: EdDSA.pm 1807 2020-09-28 11:38:28Z willem $)[2];
 
 
 =head1 NAME
@@ -41,14 +41,12 @@ public key resource record.
 
 =cut
 
-use strict;
 use integer;
-use warnings;
 use MIME::Base64;
 
-use constant EdDSA_OK => Net::DNS::SEC::libcrypto->can('EVP_PKEY_new_raw_public_key');
+use constant EdDSA_configured => Net::DNS::SEC::libcrypto->can('EVP_PKEY_new_raw_public_key');
 
-BEGIN { die unless EdDSA_OK }					# not needed on voyage
+BEGIN { die 'EdDSA disabled or application has no "use Net::DNS::SEC"' unless EdDSA_configured }
 
 
 my %parameters = (
@@ -56,18 +54,20 @@ my %parameters = (
 	16 => [1088, 57, 114],
 	);
 
+sub _index { return keys %parameters }
+
 
 sub sign {
 	my ( $class, $sigdata, $private ) = @_;
 
 	my $algorithm = $private->algorithm;
 	my ( $nid, $keylen ) = @{$parameters{$algorithm} || []};
-	die 'private key not EdDSA' unless $keylen;
+	die 'private key not EdDSA' unless $nid;
 
 	my $rawkey = pack "a$keylen", decode_base64( $private->PrivateKey );
 	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new_raw_private_key( $nid, $rawkey );
 
-	Net::DNS::SEC::libcrypto::EVP_sign( $sigdata, $evpkey );
+	return Net::DNS::SEC::libcrypto::EVP_sign( $sigdata, $evpkey );
 }
 
 
@@ -76,7 +76,7 @@ sub verify {
 
 	my $algorithm = $keyrr->algorithm;
 	my ( $nid, $keylen, $siglen ) = @{$parameters{$algorithm} || []};
-	die 'public key not EdDSA' unless $keylen;
+	die 'public key not EdDSA' unless $nid;
 
 	return unless $signature;
 
@@ -84,7 +84,7 @@ sub verify {
 	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new_raw_public_key( $nid, $rawkey );
 
 	my $sigbin = pack "a$siglen", $signature;
-	Net::DNS::SEC::libcrypto::EVP_verify( $sigdata, $sigbin, $evpkey );
+	return Net::DNS::SEC::libcrypto::EVP_verify( $sigdata, $sigbin, $evpkey );
 }
 
 
